@@ -3,7 +3,7 @@ package Genealogy::Gedcom;
 use strict;
 use warnings;
 
-our $VERSION = '0.83';
+our $VERSION = '0.86';
 
 # --------------------------------------------------
 
@@ -23,7 +23,7 @@ See L<Genealogy::Gedcom::Reader::Lexer>.
 
 L<Genealogy::Gedcom> provides a processor for GEDCOM data.
 
-See L<The GEDCOM Specification Ged551-5.pdf|http://wiki.webtrees.net/File:Ged551-5.pdf>.
+See L<The GEDCOM Specification Ged551-5.pdf|http://wiki.webtrees.net/en/Main_Page>.
 
 =head1 Distributions
 
@@ -64,7 +64,13 @@ See L<Genealogy::Gedcom::Reader::Lexer>.
 
 =head1 FAQ
 
-=head2 o What is the purpose of this set of modules?
+=head2 Does this module handle utf8?
+
+Yes. The input files are assumed to be in utf8. Files in IOS-8859-1 work automatically, too.
+
+The default output log also handles utf8.
+
+=head2 What is the purpose of this set of modules?
 
 It's the basis of a long-term project to write a new interface to GEDCOM files.
 
@@ -78,11 +84,7 @@ This is a dummy module at the moment, which just occupies the namespace.
 
 =item o Genealogy::Gedcom::Reader
 
-This employs the lexer to do the work. It may one day use a (non-existent) parser too.
-
-Run scripts/read.pl -help.
-
-read.pl is currenly a copy of lex.pl. The latter is recommended.
+This employs the lexer to do the work. It may one day use a (currently non-existent) parser too.
 
 =item o Genealogy::Gedcom::Reader::Lexer
 
@@ -94,9 +96,37 @@ See L<Genealogy::Gedcom::Reader::Lexer> for details.
 
 =back
 
+=head1 Programs Supplied as part of this Package
+
+=over 4
+
+=item o find.unused.limits.pl
+
+Helps me debug code.
+
+=item o lex.pl
+
+Runs the lexer on a file and reports some statictics. Try lex.pl -h.
+
+=item o test.all.dates.pl
+
+Reads all files in data/ and checks that any each date is valid.
+
+=back
+
+=head1 Repository
+
+L<https://github.com/ronsavage/Genealogy-Gedcom>
+
+=head1 See Also
+
+L<Genealogy::Gedcom::Date>.
+
+<Gedcom::Date>.
+
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
