@@ -5,52 +5,94 @@ use warnings;
 
 use Genealogy::Gedcom::Reader::Lexer;
 
-use Hash::FieldHash ':all';
-
 use Log::Handler;
 
-fieldhash my %input_file   => 'input_file';
-fieldhash my %items        => 'items';
-fieldhash my %lexer        => 'lexer';
-fieldhash my %logger       => 'logger';
-fieldhash my %maxlevel     => 'maxlevel';
-fieldhash my %minlevel     => 'minlevel';
-fieldhash my %report_items => 'report_items';
-fieldhash my %strict       => 'strict';
+use Moo;
 
-our $VERSION = '0.83';
+use Set::Array;
+
+use Types::Standard qw/Any Int Str/;
+
+has input_file =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has items =>
+(
+	default  => sub{return Set::Array -> new},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has logger =>
+(
+	default  => sub{return undef},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has maxlevel =>
+(
+	default  => sub{return 'notice'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has minlevel =>
+(
+	default  => sub{return 'error'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has report_items =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has strict =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+our $VERSION = '0.86';
 
 # --------------------------------------------------
 
-sub _init
+sub BUILD
 {
-	my($self, $arg)     = @_;
-	$$arg{input_file}   ||= ''; # Caller can set.
-	$$arg{lexer}        = '';
-	my($user_logger)    = defined($$arg{logger}); # Caller can set (e.g. to '').
-	$$arg{logger}       = $user_logger ? $$arg{logger} : Log::Handler -> new;
-	$$arg{maxlevel}     ||= 'warning';# Caller can set.
-	$$arg{minlevel}     ||= 'error'; # Caller can set.
-	$$arg{report_items} ||= 0;  # Caller can set.
-	$$arg{strict}       ||= 0;  # Caller can set.
-	$self               = from_hash($self, $arg);
+	my($self) = @_;
 
-	if (! $user_logger)
+	if (! defined $self -> logger)
 	{
+		$self -> logger(Log::Handler -> new);
 		$self -> logger -> add
-			(
-			 screen =>
-			 {
-				 maxlevel       => $self -> maxlevel,
-				 message_layout => '%m',
-				 minlevel       => $self -> minlevel,
-			 }
-			);
+		(
+			screen =>
+			{
+				maxlevel       => $self -> maxlevel,
+				message_layout => '%m',
+				minlevel       => $self -> minlevel,
+				utf8           => 1,
+			}
+		);
 	}
 
-	return $self;
-
-} # End of _init.
+} # End of BUILD.
 
 # --------------------------------------------------
 
@@ -58,24 +100,12 @@ sub log
 {
 	my($self, $level, $s) = @_;
 
-	$self -> logger -> $level($s);
+	$self -> logger -> $level($s) if ($self -> logger);
 
 } # End of log.
 
 # --------------------------------------------------
 
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
-# --------------------------------------------------
-
 sub run
 {
 	my($self)  = @_;
@@ -116,7 +146,7 @@ See L<Genealogy::Gedcom::Reader::Lexer>.
 
 L<Genealogy::Gedcom::Reader> provides a reader for GEDCOM data.
 
-See L<The GEDCOM Specification Ged551-5.pdf|http://wiki.webtrees.net/File:Ged551-5.pdf>.
+See L<The GEDCOM Specification Ged551-5.pdf|http://wiki.webtrees.net/en/Main_Page>.
 
 =head1 Distributions
 
@@ -157,6 +187,12 @@ See L<Genealogy::Gedcom::Reader::Lexer>.
 
 =head1 FAQ
 
+=head2 Does this module handle utf8?
+
+Yes. The input files are assumed to be in utf8. Files in IOS-8859-1 work automatically, too.
+
+The default output log also handles utf8.
+
 =head2 o What is the purpose of this set of modules?
 
 It's the basis of a long-term project to write a new interface to GEDCOM files.
@@ -173,10 +209,6 @@ This is a dummy module at the moment, which just occupies the namespace.
 
 This employs the lexer to do the work. It may one day use a (non-existent) parser too.
 
-Run scripts/read.pl -help.
-
-read.pl is currenly a copy of lex.pl. The latter is recommended.
-
 =item o Genealogy::Gedcom::Reader::Lexer
 
 This does the real work for finding tokens within GEDCOM files.
@@ -187,13 +219,19 @@ See L<Genealogy::Gedcom::Reader::Lexer> for details.
 
 =back
 
-=head2 Why did you choose L<Hash::FieldHash> over L<Moose>?
+=head1 Repository
 
-My policy is to use the light-weight L<Hash::FieldHash> for stand-alone modules and L<Moose> for applications.
+L<https://github.com/ronsavage/Genealogy-Gedcom>
+
+=head1 See Also
+
+L<Genealogy::Gedcom::Date>.
+
+<Gedcom::Date>.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
